@@ -25,7 +25,7 @@ MainWindow::MainWindow(QWidget *parent) :
     readdirs();
     oldfonts("/etc/hildon/theme/colors.config");
     progress3.setValue(20);
-    readSettings();
+    readgtkrc();
     progress3.setValue(30);
     QRegExp regexer("^\\#[0-9a-fA-F]{6,6}$");
     progress3.setValue(35);
@@ -51,7 +51,7 @@ MainWindow::MainWindow(QWidget *parent) :
     ui->Opacity->setValidator(new QRegExpValidator(regexer_opaasi, ui->Opacity));
     ui->Opacity_top->setValidator(new QRegExpValidator(regexer_opaasi, ui->Opacity_top));
     progress3.setValue(80);
-    readgtkrc();
+    readSettings();
     progress3.setValue(100);
     progress3.cancel();
 
@@ -129,6 +129,7 @@ void MainWindow::oldfonts(QString preset)
 
 void MainWindow::readdirs()
 {
+    ui->Iconset->clear();
     QDir colors("/usr/share/icons");   
     QStringList temp = colors.entryList(QDir::AllDirs | QDir::NoDotAndDotDot, QDir::DirsFirst);
     QStringList colorstobox;
@@ -166,20 +167,28 @@ void MainWindow::readgtkrc()
     icontheme.remove(QChar('\"'));
     icontheme.remove(QChar(' '));
     icontheme.simplified();
+
+    currenttheme = gtkrc.value("gtk-theme-name ");
+    currenttheme.remove(QChar('\"'));
+    currenttheme.simplified();
+
     int indeksi = ui->Iconset->findText(icontheme);
     ui->Iconset->setCurrentIndex(indeksi);
+
+    ui->label->setText(tr("Current theme: ") + currenttheme);
 }
 
 void MainWindow::writeSettings()
 {
     QSettings sett("ThemeCustomizer", "Boxes");
+    QSettings themesett("ThemeCustomizer", currenttheme);
     sett.setValue("snap", ui->Snap->text());
-    sett.setValue("fontsize", ui->FontSize->currentIndex());
+    themesett.setValue("fontsize", ui->FontSize->currentIndex());
     sett.setValue("iconset", ui->Iconset->currentIndex());
     sett.setValue("appsize", ui->lineEdit->text());
     sett.setValue("booksize", ui->lineEdit_2->text());
-    sett.setValue("opacity", ui->Opacity->text());
-    sett.setValue("opacity_top", ui->Opacity_top->text());
+    themesett.setValue("opacity", ui->Opacity->text());
+    themesett.setValue("opacity_top", ui->Opacity_top->text());
 
     QString Icons;
     if ( ui->Icons->checkState() == Qt::Checked ) {
@@ -193,19 +202,20 @@ void MainWindow::writeSettings()
 void MainWindow::readSettings()
 {
     QSettings sett("ThemeCustomizer", "Boxes");
+    QSettings themesett("ThemeCustomizer", currenttheme);
     int icons = sett.value("icons").toInt();
     int snap = sett.value("snap").toInt();
-    int fontsize = sett.value("fontsize").toInt();
+    int fontsize = themesett.value("fontsize").toInt();
 //    int iconset = sett.value("iconset").toInt();
     int appsize = sett.value("appsize").toInt();
     int booksize = sett.value("booksize").toInt();
-    int opacity = sett.value("opacity").toInt();
-    int opacity_top = sett.value("opacity_top").toInt();
+    int opacity = themesett.value("opacity").toInt();
+    int opacity_top = themesett.value("opacity_top").toInt();
     QString appsizestring = sett.value("appsize").toString();
     QString booksizestring = sett.value("booksize").toString();
     QString snapstring = sett.value("snap").toString();
-    QString opacitystring = sett.value("opacity").toString();
-    QString opacitystring_top = sett.value("opacity_top").toString();
+    QString opacitystring = themesett.value("opacity").toString();
+    QString opacitystring_top = themesett.value("opacity_top").toString();
     // ui->Icons->setCurrentIndex(icons);
     // ui->Snap->setCurrentIndex(snap);
 
@@ -761,7 +771,7 @@ void MainWindow::on_about_triggered()
     msgBox.setWindowTitle(tr("About Theme Customizer"));
     msgBox.setText("Author: d-iivil - Licence: Freeware & open source (GPL)");
     msgBox.setTextFormat(Qt::RichText);
-    msgBox.setInformativeText("<html>Version: 0.9-42<br /><a href=\"https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=ricky%40hevikaraoke%2efi&lc=FI&item_name=Here%27s%20some%20money%20for%20beer%2e&no_note=0&currency_code=EUR&bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHostedGuest\">Be a nice guy and <b>donate some money for beer</b> to author</a></html>");
+    msgBox.setInformativeText("<html>Version: 0.9-43<br /><a href=\"https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=ricky%40hevikaraoke%2efi&lc=FI&item_name=Here%27s%20some%20money%20for%20beer%2e&no_note=0&currency_code=EUR&bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHostedGuest\">Be a nice guy and <b>donate some money for beer</b> to author</a></html>");
     msgBox.setStandardButtons(QMessageBox::Ok);
     msgBox.setDefaultButton(QMessageBox::Ok);
     msgBox.button(msgBox.Ok)->setText(tr("Ok, thanks."));
