@@ -9,24 +9,28 @@
         <translation>Customiser le thème</translation>
     </message>
     <message>
-        <source>Export theme</source>
+        <source>Current theme: </source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Export theme</source>
+        <translation>Exporter le thème</translation>
+    </message>
     <message>
         <source>Import theme</source>
-        <translation type="unfinished"></translation>
+        <translation>Importer un thème</translation>
     </message>
     <message>
         <source>Exporting theme</source>
-        <translation type="unfinished"></translation>
+        <translation>Exportation du thème</translation>
     </message>
     <message>
         <source>Select .tgz file to import</source>
-        <translation type="unfinished"></translation>
+        <translation>Séléctionner un fichier .tgz pour l&apos;importer</translation>
     </message>
     <message>
         <source>Importing theme</source>
-        <translation type="unfinished"></translation>
+        <translation>Importation du thème</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="0"/>
